﻿(function () {
    // Invoking JavaScript Strict Mode
    'use strict';
    //////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
    // Definition of the RazorEvents Application                                                                                                                                                         //
    //////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
    angular.module('RazorEvents', ['ui.bootstrap', 'toastr'])
        .constant('uiCalendarConfig', {
            calendars: {}
        })
    ;
    angular.module('RazorEvents')
        .config(function ($locationProvider, $compileProvider, toastrConfig) {
            $locationProvider.html5Mode(false);
            angular.extend(toastrConfig, {
                closeButton: true,
                containerId: 'toast-container',
                extendedTimeOut: 5000,
                progressBar: true,
                positionClass: 'toast-bottom-right',
                tapToDismiss: false,
                timeOut: 5000
            });
        })
        .controller('eventsCtrl', eventsCtrl)
        .requires.push('ui.calendar')
    ;
    //////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
    // Events Module Controller                                                                                                                                                                          //
    //////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
    function eventsCtrl($window, $scope, $rootScope, $element, $location, $http, $filter, $timeout, $q, $templateCache, $compile, $uibModal, toastr, uiCalendarConfig) {
        var vm = this;
        var sf = null;
        vm.init = function (model) {
            vm.moduleId = model.ModuleID;
            vm.moduleName = model.ModuleName;
            vm.localResource = model.LocalResource;
            vm.enableRazorCartIntegration = model.EnableRazorCartIntegration;
            vm.dateFilter = model.DateFilter;
            vm.calendarConfig = model.CalendarConfig;
            vm.calendarSources = model.CalendarSources;
            vm.hideTopNavBar = model.HideTopNavBar;
            vm.hideViewsDropdown = model.HideViewsDropdown;
            vm.calendarViews = model.CalendarViews;
            vm.eventLocations = model.EventLocations;
            vm.eventCategories = model.EventCategories;
            sf = $.ServicesFramework(vm.moduleId);
            vm.initCalendarSources();
            vm.initMiniListView();
            $element.attr('ng-init', '');
        };
        vm.initCalendarSources = function () {
            vm.calendarSources.push({
                url: sf.getServiceRoot('RazorEvents') + 'Calendar/Feed',
                type: 'POST',
                beforeSend: sf.setModuleHeaders,
                data: function () {
                    return {
                        search: vm.searchTerm || '',
                        location: vm.getSelectedLocation().Value || '',
                        category: vm.getSelectedCategory().Value || ''
                    };
                },
                success: function (response) {
                    $timeout(function () {
                        vm.processing = false;
                    });
                },
                error: function (error) {
                    console.log(JSON.stringify(error));
                    $timeout(function () {
                        vm.processing = false;
                        toastr.error(error.responseText, vm.localResource['FetchError.Text']);
                    });
                }
            });
        };
        vm.initMiniListView = function () {
            $.fullCalendar.views.miniList = $.fullCalendar.View.extend({
                initialize: function () {
                    //Called once when the view is instantiated, when the user switches to the view.
                },
                render: function () {
                    //Responsible for displaying the content of the view within the already-defined jQuery element this.el.
                    vm.miniListEvents = [];
                    vm.miniListRendering = true;
                    var $miniList = $('<div>').attr({ 'ng-if': '!events.miniListRendering', 'ng-include': '\'calendar.miniList\'' });
                    $compile($miniList)($scope);
                    this.el.html($miniList);
                },
                setHeight: function (height, isAuto) {
                    //Responsible for adjusting the pixel-height of the view. if isAuto is true, the view may be it's natural height, and "height" becomes merely a suggestion.
                    if (!isAuto) {
                        this.el.height(height);
                        this.el.css('overflow', 'hidden auto');
                    }
                },
                renderEvents: function (events) {
                    //Responsible for rendering the given Event Objects.
                    $timeout(function () {
                        events.forEach(function (event) {
                            vm.miniListEvents.push({
                                title: event.title,
                                startDate: new Date(event.start._i),
                                endDate: new Date((event.end || event.start)._i),
                                allDay: event.allDay,
                                url: event.url,
                                attendeeSignup: event.attendeeSignup
                            });
                        });
                        vm.miniListEvents.sort(function (a, b) {
                            return a.startDate - b.startDate;
                        });
                        vm.miniListRendering = false;
                    });
                },
                destroyEvents: function () {
                    //Responsible for undoing everything in renderEvents.
                    vm.miniListEvents.length = 0;
                    vm.miniListRendering = true;
                },
                renderSelection: function (range) {
                    //Accepts a {start, end} object made of Moments, and must render the selection.
                },
                destroySelection: function () {
                    //Responsible for undoing everything in renderSelection.
                },
                destroy: function () {
                    //Clears the view's rendering and executes other cleanup tasks.
                    delete vm.miniListEvents;
                    delete vm.miniListRendering;
                }
            });
        };
        vm.canRender = function () {
            if (vm.calendarConfig || vm.calendarSources)
                return true;
            else
                return false;
        };
        vm.renderEvent = function (event) {
            if (event.rendering)
                return true;
            else
                return false;
        };
        vm.changeView = function (view) {
            uiCalendarConfig.calendars.razorEvents.fullCalendar('changeView', view);
        };
        vm.navigate = function (command) {
            uiCalendarConfig.calendars.razorEvents.fullCalendar(command);
        };
        vm.getView = function () {
            if (uiCalendarConfig.calendars.razorEvents && (vm.getSelectedView().Value != 'miniList' || vm.dateFilter != 'Range'))
                return uiCalendarConfig.calendars.razorEvents.fullCalendar('getView');
            else
                return { title: '' };
        };
        vm.selectView = function (view) {
            angular.forEach(vm.calendarViews, function (calendarView, index) {
                if (calendarView === view)
                    calendarView.Selected = true;
                else
                    calendarView.Selected = false;
            });
            vm.changeView(view.Value);
        };
        vm.getSelectedView = function () {
            var selected = $filter('filter')(vm.calendarViews, { Selected: true }, true);
            if (selected.length)
                return selected[0];
            else
                return vm.calendarViews[0];
        };
        vm.selectLocation = function (location) {
            angular.forEach(vm.eventLocations, function (eventLocation, index) {
                if (eventLocation === location)
                    eventLocation.Selected = true;
                else
                    eventLocation.Selected = false;
            });
            vm.processing = true;
            uiCalendarConfig.calendars.razorEvents.fullCalendar('refetchEvents');
        };
        vm.getSelectedLocation = function () {
            var selected = $filter('filter')(vm.eventLocations, { Selected: true }, true);
            if (selected.length)
                return selected[0];
            else
                return vm.eventLocations[0];
        };
        vm.selectCategory = function (category) {
            angular.forEach(vm.eventCategories, function (eventCategory, index) {
                if (eventCategory === category)
                    eventCategory.Selected = true;
                else
                    eventCategory.Selected = false;
            });
            vm.processing = true;
            uiCalendarConfig.calendars.razorEvents.fullCalendar('refetchEvents');
        };
        vm.getSelectedCategory = function () {
            var selected = $filter('filter')(vm.eventCategories, { Selected: true }, true);
            if (selected.length)
                return selected[0];
            else
                return vm.eventCategories[0];
        };
        vm.search = function () {
            if (vm.searchTerm || vm.filterContent) {
                vm.filterContent = true;
                vm.processing = true;
                uiCalendarConfig.calendars.razorEvents.fullCalendar('refetchEvents');
            }
        };
        vm.clearSearch = function () {
            vm.searchTerm = '';
            if (vm.filterContent) {
                vm.processing = true;
                uiCalendarConfig.calendars.razorEvents.fullCalendar('refetchEvents');
            }
            vm.filterContent = false;
        };
        vm.getNoEventsMessage = function () {
            return uiCalendarConfig.calendars.razorEvents.fullCalendar('getView').options.noEventsMessage || $.fullCalendar.views.list.defaults.noEventsMessage;
        };
        vm.getDateRangeDays = function (startDate, endDate) {
            return parseInt((endDate - startDate) / (1000 * 3600 * 24));
        };
    }
    // End of RazorEvents IIFE
}());