﻿(function () {
    // Invoking JavaScript Strict Mode
    'use strict';
    //////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
    // Definition of the RazorEvents Application                                                                                                                                                         //
    //////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
    angular.module('RazorEvents', ['ui.bootstrap', 'toastr'])
        .directive('destroyModel', function () {
            return {
                restrict: 'A',
                require: 'ngModel',
                link: function (scope, element, attrs, ngModel) {
                    scope.$on('$destroy', function () {
                        ngModel.$setViewValue(undefined);
                    });
                }
            };
        }).directive('matchEmptyValue', function () {
            return {
                restrict: 'A',
                require: 'ngModel',
                link: function (scope, element, attrs, ngModel) {
                    ngModel.$formatters.push(function (val) {
                        return val ? val : '';
                    });
                }
            };
        }).directive('ngConfirmClick', function () {
            return {
                priority: -1,
                restrict: 'A',
                link: function (scope, element, attrs) {
                    element.bind('click', function (e) {
                        if (attrs.ngConfirmClick && !window.confirm(attrs.ngConfirmClick)) {
                            e.stopImmediatePropagation();
                            e.preventDefault();
                        }
                    });
                }
            };
        })
        ;
    angular.module('RazorEvents')
        .config(function ($locationProvider, $compileProvider, toastrConfig) {
            $locationProvider.html5Mode(false);
            angular.extend(toastrConfig, {
                closeButton: true,
                containerId: 'toast-container',
                extendedTimeOut: 5000,
                progressBar: true,
                positionClass: 'toast-bottom-right',
                tapToDismiss: false,
                timeOut: 5000
            });
        })
        .controller('eventsCtrl', eventsCtrl)
        .requires.push('ng.ckeditor', 'thatisuday.dropzone')
        ;
    //////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
    // Events Module Controller                                                                                                                                                                          //
    //////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
    function eventsCtrl($window, $scope, $rootScope, $element, $location, $http, $filter, $timeout, $q, $templateCache, $compile, $uibModal, toastr) {
        var vm = this;
        var sf = null;
        vm.init = function (model) {
            vm.culture = model.Culture;
            vm.moduleId = model.ModuleID;
            vm.moduleName = model.ModuleName;
            vm.localResource = model.LocalResource;
            vm.baseImageSource = model.BaseImageSource;
            vm.eventList = model.EventList;
            vm.categoryList = model.CategoryList;
            vm.locationList = model.LocationList;
            vm.enableRazorCartIntegration = model.EnableRazorCartIntegration;
            vm.razorCartEmailTemplates = model.RazorCartEmailTemplates;
            vm.countries = model.Countries;
            vm.regions = model.Regions;
            vm.portalCultures = model.PortalCultures;
            sf = $.ServicesFramework(vm.moduleId);
            $element.attr('ng-init', '');
        };
        vm.repeatsDateOptions = {
            dateDisabled: function (value) {
                var disabled = false;
                if (angular.isArray(vm.current.Repeats)) {
                    angular.forEach(vm.current.Repeats, function (repeat, index) {
                        switch (vm.current.Interval) {
                            case 'Monthly':
                                if (repeat.getDate() === value.date.getDate())
                                    disabled = true;
                                break;
                            case 'Yearly':
                                if (repeat.getDate() === value.date.getDate() && repeat.getMonth() === value.date.getMonth())
                                    disabled = true;
                                break;
                        }
                    });
                }
                return disabled;
            }
        };
        vm.addRepeatDate = function () {
            if (!vm.current.Repeats)
                vm.current.Repeats = [];
            if (!angular.isArray(vm.current.Repeats))
                vm.current.Repeats = [];
            vm.current.Repeats.push(vm.state.RepeatsDate);
            vm.state.RepeatsDate = null;
        };
        vm.removeRepeatDate = function (index) {
            if (!vm.current.Repeats)
                vm.current.Repeats = [];
            if (!angular.isArray(vm.current.Repeats))
                vm.current.Repeats = [];
            vm.current.Repeats.splice(index, 1);
        };
        vm.listCountryRegions = function (countryCode) {
            var deferred = $q.defer();
            $http.get(sf.getServiceRoot('RazorEvents') + 'Location/Regions', {
                params: { 'Country': countryCode },
                headers: { 'Content-Type': 'application/json', 'ModuleId': sf.getModuleId(), 'TabId': sf.getTabId(), 'RequestVerificationToken': sf.getAntiForgeryValue() }
            }).then(function (response) {
                deferred.resolve(response.data);
            }).catch(function (error) {
                deferred.reject(error.data);
            });
            return deferred.promise;
        };
        vm.manageEvent = function (index) {
            var event = vm.eventList[index];
            if (event) {
                vm.current = angular.copy(event);
                vm.current.Start = new Date(vm.current.Start);
                vm.current.End = new Date(vm.current.End);
                if (vm.current.NotAfter)
                    vm.current.NotAfter = new Date(vm.current.NotAfter);
                if (angular.isArray(vm.current.Repeats)) {
                    angular.forEach(vm.current.Repeats, function (repeat, index) {
                        vm.current.Repeats[index] = new Date(repeat);
                    });
                }
            }
            else
                vm.current = null;
            var modal = $uibModal.open({
                animation: true,
                keyboard: false,
                backdrop: 'static',
                ariaLabelledBy: 'modal-title',
                ariaDescribedBy: 'modal-body',
                templateUrl: 'manageEvent.modal',
                appendTo: $element,
                scope: $scope,
                size: 'lg',
                resolve: {
                    data: function () {
                        return vm.eventList;
                    }
                }
            });
            vm.cancel = function () {
                vm.current = null;
                vm.submitted = false;
                modal.close();
            };
            vm.save = function () {
                vm.processing = true;
                $http.post(sf.getServiceRoot('RazorEvents') + 'Event/Save', { 'Event': vm.current }, {
                    headers: { 'Content-Type': 'application/json', 'ModuleId': sf.getModuleId(), 'TabId': sf.getTabId(), 'RequestVerificationToken': sf.getAntiForgeryValue() }
                }).then(function (response) {
                    toastr.success(vm.localResource['SaveSuccess.Text'], vm.moduleName);
                    modal.close();
                    if (event)
                        vm.eventList[index] = response.data.Event;
                    else
                        vm.eventList.push(response.data.Event);
                    vm.processing = false;
                }).catch(function (error) {
                    toastr.error(vm.localResource['SaveError.Text'], vm.moduleName);
                    console.log(JSON.stringify(error));
                    vm.processing = false;
                });
            };
        };
        vm.deleteEvent = function (index) {
            var event = vm.eventList[index];
            if (event) {
                vm.processing = true;
                $http.delete(sf.getServiceRoot('RazorEvents') + 'Event/Delete', {
                    data: { 'EventId': event.Id },
                    headers: { 'Content-Type': 'application/json', 'ModuleId': sf.getModuleId(), 'TabId': sf.getTabId(), 'RequestVerificationToken': sf.getAntiForgeryValue() }
                }).then(function (response) {
                    toastr.success(vm.localResource['SaveSuccess.Text'], vm.moduleName);
                    vm.eventList.splice(index, 1);
                    vm.processing = false;
                }).catch(function (error) {
                    toastr.error(vm.localResource['SaveError.Text'], vm.moduleName);
                    console.log(JSON.stringify(error));
                    vm.processing = false;
                });
            }
        };
        vm.optionGroupRequired = function (optionGroup, groupIndex) {
            return optionGroup.Required || optionGroup.Options.filter(function (option) {
                return option.Name;
            }).length > 0 || vm.current.OptionGroups.filter(function (optGrp, i) {
                return i > groupIndex && !optGrp.Delete && optGrp.Title;
            }).length > 0;
        };
        vm.newOptionGroupDisabled = function () {
            return vm.current.OptionGroups.filter(function (optGrp) {
                return !optGrp.Delete && !optGrp.Title;
            }).length > 0;
        };
        vm.newOptionGroup = function () {
            vm.current.OptionGroups.push({ Options: [{}] });
        };
        vm.deleteOptionGroup = function (optionGroup) {
            optionGroup.Delete = true;
        };
        vm.newOptionDisabled = function (optionGroup) {
            return optionGroup.Options.filter(function (opt) {
                return !opt.Delete && !opt.Name;
            }).length > 0;
        };
        vm.newOption = function (optionGroup) {
            optionGroup.Options.push({});
        };
        vm.deleteOption = function (option) {
            option.Delete = true;
        };
        vm.manageImages = function (index) {
            var event = vm.eventList[index];
            if (event) {
                vm.current = angular.copy(event);
                vm.dzOptions = {
                    timeout: 45000,
                    maxFilesize: 8,
                    uploadMultiple: true,
                    thumbnailWidth: 182,
                    thumbnailHeight: 182,
                    acceptedFiles: 'images/jpg, image/jpeg, image/png',
                    previewTemplate: $templateCache.get('manageImages.dropZone'),
                    addRemoveLinks: false,
                    dictRemoveFile: 'Delete',
                    type: 'POST',
                    url: sf.getServiceRoot('RazorEvents') + 'Event/UploadImages',
                    params: { 'EventId': event.Id },
                    headers: { 'ModuleId': sf.getModuleId(), 'TabId': sf.getTabId(), 'RequestVerificationToken': sf.getAntiForgeryValue() },
                    init: function () {
                        $timeout(function () {
                            var dropZone = vm.dzMethods.getDropzone();
                            if (dropZone) {
                                angular.forEach(vm.current.Images, function (image, index) {
                                    var serverImageUrl = $window.location.origin + vm.baseImageSource + image.ImageSource + '?Id=' + image.Id;
                                    var mockFile = { name: image.ImageSource, dataURL: serverImageUrl, size: 500, status: Dropzone.ADDED, accepted: true, imageInfo: image, isMocked: true };
                                    dropZone.files.push(mockFile);
                                    dropZone.emit("addedfile", mockFile);
                                    dropZone.emit("processing", mockFile);
                                    dropZone.emit("success", mockFile);
                                    dropZone.emit("complete", mockFile);
                                });
                            }
                        });
                    }
                };
                vm.dzCallbacks = {
                    addedfile: function (file) {
                        vm.processing = true;
                        if (file.isMocked) {
                            var dropZone = vm.dzMethods.getDropzone();
                            if (dropZone) {
                                dropZone.createThumbnailFromUrl(file, dropZone.options.thumbnailWidth, dropZone.options.thumbnailHeight, dropZone.options.thumbnailMethod, true, function (thumbnail) {
                                    dropZone.emit('thumbnail', file, thumbnail);
                                });
                            }
                        }
                    },
                    complete: function (file) {
                        if (file.status !== Dropzone.ERROR && !file.isMocked) {
                            var images = JSON.parse(file.xhr.response);
                            var image = $filter('filter')(images, { ImageSource: file.name }, true);
                            if (image.length) {
                                file.imageInfo = image[0];
                                vm.current.Images.push(file.imageInfo);
                                event.Images.push(file.imageInfo);
                            }
                            toastr.success(vm.localResource['SaveSuccess.Text'], vm.moduleName);
                        }
                        var titleAttr = angular.element(file.previewElement).find('[data-field="titleAttr"]');
                        if (titleAttr) {
                            angular.element(titleAttr).attr('ng-model', 'events.current.ImagesDetails[' + file.imageInfo.Id + '].TitleAttr');
                            angular.element(titleAttr).attr('ng-init', 'events.current.ImagesDetails[' + file.imageInfo.Id + '].TitleAttr = \'' + file.imageInfo.TitleAttr + '\'');
                            $compile(titleAttr)($scope);
                        }
                        var altAttr = angular.element(file.previewElement).find('[data-field="altAttr"]');
                        if (altAttr) {
                            angular.element(altAttr).attr('ng-model', 'events.current.ImagesDetails[' + file.imageInfo.Id + '].AltAttr');
                            angular.element(altAttr).attr('ng-init', 'events.current.ImagesDetails[' + file.imageInfo.Id + '].AltAttr = \'' + file.imageInfo.AltAttr + '\'');
                            $compile(altAttr)($scope);
                        }
                        var caption = angular.element(file.previewElement).find('[data-field="caption"]');
                        if (caption) {
                            angular.element(caption).attr('ng-model', 'events.current.ImagesDetails[' + file.imageInfo.Id + '].Caption');
                            angular.element(caption).attr('ng-init', 'events.current.ImagesDetails[' + file.imageInfo.Id + '].Caption = \'' + file.imageInfo.Caption + '\'');
                            $compile(caption)($scope);
                        }
                        var description = angular.element(file.previewElement).find('[data-field="description"]');
                        if (description) {
                            angular.element(description).attr('ng-model', 'events.current.ImagesDetails[' + file.imageInfo.Id + '].Description');
                            angular.element(description).attr('ng-init', 'events.current.ImagesDetails[' + file.imageInfo.Id + '].Description = \'' + file.imageInfo.Description + '\'');
                            $compile(description)($scope);
                        }
                        vm.processing = false;
                    },
                    removedfile: function (file) {
                        if (file.status !== Dropzone.ERROR) {
                            var image = $filter('filter')(vm.current.Images, { Id: file.imageInfo.Id }, true);
                            if (image.length) {
                                vm.processing = true;
                                $http.delete(sf.getServiceRoot('RazorEvents') + 'Event/DeleteImage', {
                                    data: { 'ImageId': image[0].Id },
                                    headers: { 'Content-Type': 'application/json', 'ModuleId': sf.getModuleId(), 'TabId': sf.getTabId(), 'RequestVerificationToken': sf.getAntiForgeryValue() }
                                }).then(function (response) {
                                    toastr.success(vm.localResource['SaveSuccess.Text'], vm.moduleName);
                                    var index = vm.current.Images.indexOf(image[0]);
                                    vm.current.Images.splice(index, 1);
                                    event.Images.splice(index, 1);
                                    vm.processing = false;
                                }).catch(function (error) {
                                    toastr.error(vm.localResource['SaveError.Text'], vm.moduleName);
                                    console.log(JSON.stringify(error));
                                    vm.processing = false;
                                });
                            }
                        }
                    }
                };
                var modal = $uibModal.open({
                    animation: true,
                    keyboard: false,
                    backdrop: 'static',
                    ariaLabelledBy: 'modal-title',
                    ariaDescribedBy: 'modal-body',
                    templateUrl: 'manageImages.modal',
                    appendTo: $element,
                    scope: $scope,
                    size: 'xl',
                    resolve: {
                        data: function () {
                            return vm.eventList;
                        }
                    }
                });
                vm.cancel = function () {
                    vm.current = null;
                    vm.submitted = false;
                    modal.close();
                };
                vm.save = function () {
                    vm.processing = true;
                    $http.post(sf.getServiceRoot('RazorEvents') + 'Event/SaveImages', { 'EventId': vm.current.Id, 'ImagesDetails': vm.current.ImagesDetails }, {
                        headers: { 'Content-Type': 'application/json', 'ModuleId': sf.getModuleId(), 'TabId': sf.getTabId(), 'RequestVerificationToken': sf.getAntiForgeryValue() }
                    }).then(function (response) {
                        toastr.success(vm.localResource['SaveSuccess.Text'], vm.moduleName);
                        if (event) {
                            event.Images = response.data.Images;
                            modal.close();
                        }
                        vm.processing = false;
                    }).catch(function (error) {
                        toastr.error(vm.localResource['SaveError.Text'], vm.moduleName);
                        console.log(JSON.stringify(error));
                        vm.processing = false;
                    });
                };
            }
            else
                vm.current = null;
        };
        vm.localizeEvent = function (index) {
            var event = vm.eventList[index];
            if (event) {
                vm.current = angular.copy(event);
                vm.current.CultureName = vm.culture;
                var modal = $uibModal.open({
                    animation: true,
                    keyboard: false,
                    backdrop: 'static',
                    ariaLabelledBy: 'modal-title',
                    ariaDescribedBy: 'modal-body',
                    templateUrl: 'manageEventLocales.modal',
                    appendTo: $element,
                    scope: $scope,
                    size: 'lg',
                    resolve: {
                        data: function () {
                            return vm.eventList;
                        }
                    }
                });
                vm.cancel = function () {
                    vm.current = null;
                    vm.submitted = false;
                    modal.close();
                };
                vm.save = function () {
                    vm.processing = true;
                    $http.post(sf.getServiceRoot('RazorEvents') + 'Event/SaveLocales', { 'EventId': vm.current.Id, 'EventLocales': vm.current.Locales }, {
                        headers: { 'Content-Type': 'application/json', 'ModuleId': sf.getModuleId(), 'TabId': sf.getTabId(), 'RequestVerificationToken': sf.getAntiForgeryValue() }
                    }).then(function (response) {
                        toastr.success(vm.localResource['SaveSuccess.Text'], vm.moduleName);
                        if (event) {
                            event.Locales = response.data.EventLocales;
                            modal.close();
                        }
                        vm.processing = false;
                    }).catch(function (error) {
                        toastr.error(vm.localResource['SaveError.Text'], vm.moduleName);
                        console.log(JSON.stringify(error));
                        vm.processing = false;
                    });
                };
            }
            else
                vm.current = null;
        };
        vm.manageCategory = function (index) {
            var category = vm.categoryList[index];
            if (category)
                vm.current = angular.copy(category);
            else
                vm.current = null;
            var modal = $uibModal.open({
                animation: true,
                keyboard: false,
                backdrop: 'static',
                ariaLabelledBy: 'modal-title',
                ariaDescribedBy: 'modal-body',
                templateUrl: 'manageCategory.modal',
                appendTo: $element,
                scope: $scope,
                size: 'lg',
                resolve: {
                    data: function () {
                        return vm.categoryList;
                    }
                }
            });
            vm.cancel = function () {
                vm.current = null;
                vm.submitted = false;
                modal.close();
            };
            vm.save = function () {
                vm.processing = true;
                $http.post(sf.getServiceRoot('RazorEvents') + 'Category/Save', { 'Category': vm.current }, {
                    headers: { 'Content-Type': 'application/json', 'ModuleId': sf.getModuleId(), 'TabId': sf.getTabId(), 'RequestVerificationToken': sf.getAntiForgeryValue() }
                }).then(function (response) {
                    toastr.success(vm.localResource['SaveSuccess.Text'], vm.moduleName);
                    modal.close();
                    if (category)
                        vm.categoryList[index] = response.data.Category;
                    else
                        vm.categoryList.push(response.data.Category);
                    vm.processing = false;
                }).catch(function (error) {
                    toastr.error(vm.localResource['SaveError.Text'], vm.moduleName);
                    console.log(JSON.stringify(error));
                    vm.processing = false;
                });
            };
        };
        vm.deleteCategory = function (index) {
            var category = vm.categoryList[index];
            if (category) {
                vm.processing = true;
                $http.delete(sf.getServiceRoot('RazorEvents') + 'Category/Delete', {
                    data: { 'CategoryId': category.Id },
                    headers: { 'Content-Type': 'application/json', 'ModuleId': sf.getModuleId(), 'TabId': sf.getTabId(), 'RequestVerificationToken': sf.getAntiForgeryValue() }
                }).then(function (response) {
                    toastr.success(vm.localResource['SaveSuccess.Text'], vm.moduleName);
                    vm.categoryList.splice(index, 1);
                    vm.processing = false;
                }).catch(function (error) {
                    toastr.error(vm.localResource['SaveError.Text'], vm.moduleName);
                    console.log(JSON.stringify(error));
                    vm.processing = false;
                });
            }
        };
        vm.localizeCategory = function (index) {
            var category = vm.categoryList[index];
            if (category) {
                vm.current = angular.copy(category);
                vm.current.CultureName = vm.culture;
                var modal = $uibModal.open({
                    animation: true,
                    keyboard: false,
                    backdrop: 'static',
                    ariaLabelledBy: 'modal-title',
                    ariaDescribedBy: 'modal-body',
                    templateUrl: 'manageCategoryLocales.modal',
                    appendTo: $element,
                    scope: $scope,
                    size: 'lg',
                    resolve: {
                        data: function () {
                            return vm.categoryList;
                        }
                    }
                });
                vm.cancel = function () {
                    vm.current = null;
                    vm.submitted = false;
                    modal.close();
                };
                vm.save = function () {
                    vm.processing = true;
                    $http.post(sf.getServiceRoot('RazorEvents') + 'Category/SaveLocales', { 'CategoryId': vm.current.Id, 'CategoryLocales': vm.current.Locales }, {
                        headers: { 'Content-Type': 'application/json', 'ModuleId': sf.getModuleId(), 'TabId': sf.getTabId(), 'RequestVerificationToken': sf.getAntiForgeryValue() }
                    }).then(function (response) {
                        toastr.success(vm.localResource['SaveSuccess.Text'], vm.moduleName);
                        if (category) {
                            category.Locales = response.data.CategoryLocales;
                            modal.close();
                        }
                        vm.processing = false;
                    }).catch(function (error) {
                        toastr.error(vm.localResource['SaveError.Text'], vm.moduleName);
                        console.log(JSON.stringify(error));
                        vm.processing = false;
                    });
                };
            }
            else
                vm.current = null;
        };
        vm.manageLocation = function (index) {
            var location = vm.locationList[index];
            if (location) {
                vm.current = angular.copy(location);
                vm.listCountryRegions(vm.current.Country).then(function (regions) {
                    vm.regions = regions;
                });
            }
            else
                vm.current = null;
            var modal = $uibModal.open({
                animation: true,
                keyboard: false,
                backdrop: 'static',
                ariaLabelledBy: 'modal-title',
                ariaDescribedBy: 'modal-body',
                templateUrl: 'manageLocation.modal',
                appendTo: $element,
                scope: $scope,
                size: 'lg',
                resolve: {
                    data: function () {
                        return vm.locationList;
                    }
                }
            });
            vm.updateRegions = function () {
                vm.processing = true;
                if (vm.current.Country) {
                    vm.listCountryRegions(vm.current.Country).then(function (regions) {
                        vm.regions = regions;
                        vm.current.Region = null;
                        vm.processing = false;
                    }, function (error) {
                        console.log(JSON.stringify(error));
                        vm.processing = false;
                    });
                }
            };
            vm.cancel = function () {
                vm.current = null;
                vm.submitted = false;
                modal.close();
            };
            vm.save = function () {
                vm.processing = true;
                $http.post(sf.getServiceRoot('RazorEvents') + 'Location/Save', { 'Location': vm.current }, {
                    headers: { 'Content-Type': 'application/json', 'ModuleId': sf.getModuleId(), 'TabId': sf.getTabId(), 'RequestVerificationToken': sf.getAntiForgeryValue() }
                }).then(function (response) {
                    toastr.success(vm.localResource['SaveSuccess.Text'], vm.moduleName);
                    modal.close();
                    if (location)
                        vm.locationList[index] = response.data.Location;
                    else
                        vm.locationList.push(response.data.Location);
                    vm.processing = false;
                }).catch(function (error) {
                    toastr.error(vm.localResource['SaveError.Text'], vm.moduleName);
                    console.log(JSON.stringify(error));
                    vm.processing = false;
                });
            };
        };
        vm.deleteLocation = function (index) {
            var location = vm.locationList[index];
            if (location) {
                vm.processing = true;
                $http.delete(sf.getServiceRoot('RazorEvents') + 'Location/Delete', {
                    data: { 'LocationId': location.Id },
                    headers: { 'Content-Type': 'application/json', 'ModuleId': sf.getModuleId(), 'TabId': sf.getTabId(), 'RequestVerificationToken': sf.getAntiForgeryValue() }
                }).then(function (response) {
                    toastr.success(vm.localResource['SaveSuccess.Text'], vm.moduleName);
                    vm.locationList.splice(index, 1);
                    vm.processing = false;
                }).catch(function (error) {
                    toastr.error(vm.localResource['SaveError.Text'], vm.moduleName);
                    console.log(JSON.stringify(error));
                    vm.processing = false;
                });
            }
        };
        vm.localizeLocation = function (index) {
            var location = vm.locationList[index];
            if (location) {
                vm.current = angular.copy(location);
                vm.current.CultureName = vm.culture;
                var modal = $uibModal.open({
                    animation: true,
                    keyboard: false,
                    backdrop: 'static',
                    ariaLabelledBy: 'modal-title',
                    ariaDescribedBy: 'modal-body',
                    templateUrl: 'manageLocationLocales.modal',
                    appendTo: $element,
                    scope: $scope,
                    size: 'lg',
                    resolve: {
                        data: function () {
                            return vm.locationList;
                        }
                    }
                });
                vm.cancel = function () {
                    vm.current = null;
                    vm.submitted = false;
                    modal.close();
                };
                vm.save = function () {
                    vm.processing = true;
                    $http.post(sf.getServiceRoot('RazorEvents') + 'Location/SaveLocales', { 'LocationId': vm.current.Id, 'LocationLocales': vm.current.Locales }, {
                        headers: { 'Content-Type': 'application/json', 'ModuleId': sf.getModuleId(), 'TabId': sf.getTabId(), 'RequestVerificationToken': sf.getAntiForgeryValue() }
                    }).then(function (response) {
                        toastr.success(vm.localResource['SaveSuccess.Text'], vm.moduleName);
                        if (location) {
                            location.Locales = response.data.LocationLocales;
                            modal.close();
                        }
                        vm.processing = false;
                    }).catch(function (error) {
                        toastr.error(vm.localResource['SaveError.Text'], vm.moduleName);
                        console.log(JSON.stringify(error));
                        vm.processing = false;
                    });
                };
            }
            else
                vm.current = null;
        };
    }
    // End of RazorEvents IIFE
}());