﻿(function () {
    // Invoking JavaScript Strict Mode
    'use strict';
    //////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
    // Definition of the RazorEvents Application                                                                                                                                                        //
    //////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
    angular.module('RazorEvents', ['ui.bootstrap', 'toastr'])
        .directive('ngConfirmClick', function () {
            return {
                priority: -1,
                restrict: 'A',
                link: function (scope, element, attrs) {
                    element.bind('click', function (e) {
                        if (attrs.ngConfirmClick && !window.confirm(attrs.ngConfirmClick)) {
                            e.stopImmediatePropagation();
                            e.preventDefault();
                        }
                    });
                }
            };
        })
    ;
    angular.module('RazorEvents')
        .config(function ($locationProvider, $compileProvider, toastrConfig) {
            $locationProvider.html5Mode(false);
            angular.extend(toastrConfig, {
                closeButton: true,
                containerId: 'toast-container',
                extendedTimeOut: 5000,
                progressBar: true,
                positionClass: 'toast-bottom-right',
                tapToDismiss: false,
                timeOut: 5000
            });
        })
        .controller('eventsCtrl', eventsCtrl)
        .requires.push('ui.ace')
        ;
    //////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
    // Events Module Controller                                                                                                                                                                         //
    //////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
    function eventsCtrl($window, $scope, $rootScope, $element, $location, $http, $filter, $timeout, $q, $templateCache, $compile, $uibModal, toastr) {
        var vm = this;
        var sf = null;
        vm.init = function (model) {
            vm.moduleId = model.ModuleID;
            vm.moduleName = model.ModuleName;
            vm.localResource = model.LocalResource;
            vm.viewFolder = model.ViewFolder;
            vm.viewMode = model.ViewMode;
            sf = $.ServicesFramework(vm.moduleId);
            $element.attr('ng-init', '');
        };
        vm.copy = function () {
            vm.processing = true;
            $http.put(sf.getServiceRoot('RazorEvents') + 'View/Copy', { 'Files': null }, {
                headers: { 'Content-Type': 'application/json', 'ModuleId': sf.getModuleId(), 'TabId': sf.getTabId(), 'RequestVerificationToken': sf.getAntiForgeryValue() }
            }).then(function (response) {
                toastr.success(vm.localResource['CopySuccess.Text'], vm.moduleName);
                vm.viewFolder.FolderStructure = response.data.FolderStructure;
                vm.requiredResetMessage = true;
                vm.processing = false;
            }).catch(function (error) {
                toastr.error(vm.localResource['CopyError.Text'], vm.moduleName);
                console.log(JSON.stringify(error));
                vm.processing = false;
            });
        };
        vm.delete = function () {
            vm.processing = true;
            $http.delete(sf.getServiceRoot('RazorEvents') + 'View/Delete', {
                headers: { 'Content-Type': 'application/json', 'ModuleId': sf.getModuleId(), 'TabId': sf.getTabId(), 'RequestVerificationToken': sf.getAntiForgeryValue() },
                data: { 'Files': null }
            }).then(function (response) {
                toastr.success(vm.localResource['DeleteSuccess.Text'], vm.moduleName);
                vm.viewFolder.FolderStructure = response.data.FolderStructure;
                vm.requiredResetMessage = true;
                vm.processing = false;
            }).catch(function (error) {
                toastr.error(vm.localResource['DeleteError.Text'], vm.moduleName);
                console.log(JSON.stringify(error));
                vm.processing = false;
            });
        };
        vm.select = function (event, item) {
            $timeout(function () {
                if (item.Type === 'FileStructure' && item.Selectable) {
                    angular.forEach(vm.viewFolder.FolderStructure, function (value, key) {
                        if (value.Type === 'FolderStructure') {
                            angular.forEach(value.Items, function (value, key) {
                                if (value.Selectable)
                                    value.IsSelected = false;
                            });
                        }
                        else if (value.Type === 'FileStructure') {
                            if (value.Selectable)
                                value.IsSelected = false;
                        }
                    });
                    item.IsSelected = true;
                }
                else if (item.Type === 'FolderStructure') {
                    item.Opened = !item.Opened;
                }
            });
            event.stopPropagation();
        };
        vm.edit = function () {
            var selectedFile;
            angular.forEach(vm.viewFolder.FolderStructure, function (value, key) {
                if (value.Type === 'FolderStructure') {
                    angular.forEach(value.Items, function (value, key) {
                        if (value.IsSelected)
                            selectedFile = value;
                    });
                }
                else if (value.Type === 'FileStructure') {
                    if (value.IsSelected)
                        selectedFile = value;
                }
            });
            if (selectedFile) {
                vm.processing = true;
                $http.get(sf.getServiceRoot('RazorEvents') + 'View/Content', {
                    headers: { 'Content-Type': 'application/json', 'ModuleId': sf.getModuleId(), 'TabId': sf.getTabId(), 'RequestVerificationToken': sf.getAntiForgeryValue() },
                    params: { 'ViewPath': selectedFile.Path }
                }).then(function (response) {
                    vm.file = response.data;
                    vm.viewMode = 'ViewEditor';
                    vm.processing = false;
                }).catch(function (error) {
                    toastr.error(vm.localResource['LoadContentError.Text'], vm.moduleName);
                    console.log(JSON.stringify(error));
                    vm.processing = false;
                });
            }
            else {
                toastr.warning(vm.localResource['NoSelectedView.Text'], vm.moduleName);
            }
        };
        vm.save = function () {
            vm.processing = true;
            $http.post(sf.getServiceRoot('RazorEvents') + 'View/Content', vm.file, {
                headers: { 'Content-Type': 'application/json', 'ModuleId': sf.getModuleId(), 'TabId': sf.getTabId(), 'RequestVerificationToken': sf.getAntiForgeryValue() }
            }).then(function (response) {
                toastr.success(vm.localResource['SaveSuccess.Text'], vm.moduleName);
                vm.processing = false;
            }).catch(function (error) {
                toastr.error(vm.localResource['SaveError.Text'], vm.moduleName);
                toastr.error(error.data.Message, vm.moduleName);
                console.log(JSON.stringify(error));
                vm.processing = false;
            });
        };
        vm.close = function () {
            vm.file = {};
            vm.viewMode = 'Viewset';
        };
    }
    // End of RazorEvents IIFE
}());